==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/SpecificControllerConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SpecificControllerConfigBuilder extends SpecificControllerConfigFluentImpl<SpecificControllerConfigBuilder> implements VisitableBuilder<SpecificControllerConfig,SpecificControllerConfigBuilder>{
  public SpecificControllerConfigBuilder() {
    this(false);
  }
  public SpecificControllerConfigBuilder(Boolean validationEnabled) {
    this(new SpecificControllerConfig(), validationEnabled);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SpecificControllerConfig(), validationEnabled);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent,SpecificControllerConfig instance) {
    this(fluent, instance, false);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent,SpecificControllerConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConfig(instance.getConfig());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfig instance) {
    this(instance,false);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SpecificControllerConfigFluent<?> fluent;
  Boolean validationEnabled;
  public SpecificControllerConfig build() {
    SpecificControllerConfig buildable = new SpecificControllerConfig(fluent.getConfig(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SpecificControllerConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SpecificControllerConfigBuilder extends SpecificControllerConfigFluent<SpecificControllerConfigBuilder> implements VisitableBuilder<SpecificControllerConfig,SpecificControllerConfigBuilder>{
  public SpecificControllerConfigBuilder() {
    this(false);
  }
  public SpecificControllerConfigBuilder(Boolean validationEnabled) {
    this(new SpecificControllerConfig(), validationEnabled);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SpecificControllerConfig(), validationEnabled);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent,SpecificControllerConfig instance) {
    this(fluent, instance, false);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfigFluent<?> fluent,SpecificControllerConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SpecificControllerConfig());

    if (instance != null) {
      fluent.withConfig(instance.getConfig());
      fluent.withName(instance.getName());
      fluent.withConfig(instance.getConfig());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfig instance) {
    this(instance,false);
  }
  public SpecificControllerConfigBuilder(SpecificControllerConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SpecificControllerConfig());

    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withName(instance.getName());
      this.withConfig(instance.getConfig());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SpecificControllerConfigFluent<?> fluent;
  Boolean validationEnabled;
  public SpecificControllerConfig build() {
    SpecificControllerConfig buildable = new SpecificControllerConfig(fluent.buildConfig(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
